# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ImageData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "blob",
            "src",
            "type",
        }
        
        class properties:
            src = schemas.StrSchema
            blob = schemas.StrSchema
        
            @staticmethod
            def type() -> typing.Type['DataTypeEnum']:
                return DataTypeEnum
            __annotations__ = {
                "src": src,
                "blob": blob,
                "type": type,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    blob: MetaOapg.properties.blob
    src: MetaOapg.properties.src
    type: 'DataTypeEnum'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["blob"]) -> MetaOapg.properties.blob: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["src"]) -> MetaOapg.properties.src: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'DataTypeEnum': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["blob"], typing_extensions.Literal["src"], typing_extensions.Literal["type"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["blob"]) -> MetaOapg.properties.blob: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["src"]) -> MetaOapg.properties.src: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> 'DataTypeEnum': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["blob"], typing_extensions.Literal["src"], typing_extensions.Literal["type"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        blob: typing.Union[MetaOapg.properties.blob, str, ],
        src: typing.Union[MetaOapg.properties.src, str, ],
        type: 'DataTypeEnum',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'ImageData':
        return super().__new__(
            cls,
            *args,
            blob=blob,
            src=src,
            type=type,
            _configuration=_configuration,
        )

from openapi_client.model.data_type_enum import DataTypeEnum
