# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Dataset(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "access",
            "organization",
            "name",
            "_id",
        }
        
        class properties:
            _id = schemas.StrSchema
            
            
            class name(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'name':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            organization = schemas.StrSchema
        
            @staticmethod
            def access() -> typing.Type['DatasetAccess']:
                return DatasetAccess
            createdAt = schemas.StrSchema
            sourceDatasetId = schemas.StrSchema
        
            @staticmethod
            def latestValidVersion() -> typing.Type['DatasetVersion']:
                return DatasetVersion
        
            @staticmethod
            def latestVersion() -> typing.Type['DatasetVersion']:
                return DatasetVersion
            __annotations__ = {
                "_id": _id,
                "name": name,
                "organization": organization,
                "access": access,
                "createdAt": createdAt,
                "sourceDatasetId": sourceDatasetId,
                "latestValidVersion": latestValidVersion,
                "latestVersion": latestVersion,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    access: 'DatasetAccess'
    organization: MetaOapg.properties.organization
    name: MetaOapg.properties.name
    _id: MetaOapg.properties._id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["access"]) -> 'DatasetAccess': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sourceDatasetId"]) -> MetaOapg.properties.sourceDatasetId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["latestValidVersion"]) -> 'DatasetVersion': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["latestVersion"]) -> 'DatasetVersion': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["access"], typing_extensions.Literal["organization"], typing_extensions.Literal["name"], typing_extensions.Literal["_id"], typing_extensions.Literal["sourceDatasetId"], typing_extensions.Literal["latestValidVersion"], typing_extensions.Literal["latestVersion"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["access"]) -> 'DatasetAccess': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sourceDatasetId"]) -> typing.Union[MetaOapg.properties.sourceDatasetId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["latestValidVersion"]) -> typing.Union['DatasetVersion', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["latestVersion"]) -> typing.Union['DatasetVersion', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["access"], typing_extensions.Literal["organization"], typing_extensions.Literal["name"], typing_extensions.Literal["_id"], typing_extensions.Literal["sourceDatasetId"], typing_extensions.Literal["latestValidVersion"], typing_extensions.Literal["latestVersion"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, ],
        access: 'DatasetAccess',
        organization: typing.Union[MetaOapg.properties.organization, str, ],
        name: typing.Union[MetaOapg.properties.name, None, str, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        sourceDatasetId: typing.Union[MetaOapg.properties.sourceDatasetId, str, schemas.Unset] = schemas.unset,
        latestValidVersion: typing.Union['DatasetVersion', schemas.Unset] = schemas.unset,
        latestVersion: typing.Union['DatasetVersion', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Dataset':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            access=access,
            organization=organization,
            name=name,
            _id=_id,
            sourceDatasetId=sourceDatasetId,
            latestValidVersion=latestValidVersion,
            latestVersion=latestVersion,
            _configuration=_configuration,
        )

from openapi_client.model.dataset_access import DatasetAccess
from openapi_client.model.dataset_version import DatasetVersion
