# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Point(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    In order to minimize the size of the response and not return repeating param names for tens of thousands of values,
the Point key names (xField key, yField key and metadata keys) are stored in the metadata section since they are the same for all charts in the response.
The first element in the tuple (the NumberOrString) is the xField value
The second element in the tuiple (the number) is the yField value
the third element in the tuple (the NumerOrString[]) is an array of numbers or string which are the values for the different metadata elements as shown in the metadata section of the response
The order of the metadata field names array correlates to the order of this metadata array.
    """


    class MetaOapg:
        
        @staticmethod
        def items() -> typing.Type['PointValueTypes']:
            return PointValueTypes

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple['PointValueTypes'], typing.List['PointValueTypes']],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Point':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> 'PointValueTypes':
        return super().__getitem__(i)

from openapi_client.model.point_value_types import PointValueTypes
