# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class LeapDataType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "Image": "IMAGE",
            "Text": "TEXT",
            "Graph": "GRAPH",
            "HorizontalBar": "HORIZONTAL_BAR",
            "ImageMask": "IMAGE_MASK",
            "TextMask": "TEXT_MASK",
            "ImageWithBBox": "IMAGE_WITH_BBOX",
        }
    
    @schemas.classproperty
    def IMAGE(cls):
        return cls("Image")
    
    @schemas.classproperty
    def TEXT(cls):
        return cls("Text")
    
    @schemas.classproperty
    def GRAPH(cls):
        return cls("Graph")
    
    @schemas.classproperty
    def HORIZONTAL_BAR(cls):
        return cls("HorizontalBar")
    
    @schemas.classproperty
    def IMAGE_MASK(cls):
        return cls("ImageMask")
    
    @schemas.classproperty
    def TEXT_MASK(cls):
        return cls("TextMask")
    
    @schemas.classproperty
    def IMAGE_WITH_BBOX(cls):
        return cls("ImageWithBBox")
