# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class HorizontalBarScatterLabel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "horizontal_bar_visualizations",
            "type",
        }
        
        class properties:
            type = schemas.StrSchema
            
            
            class horizontal_bar_visualizations(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['HorizontalBarViz']:
                        return HorizontalBarViz
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['HorizontalBarViz'], typing.List['HorizontalBarViz']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'horizontal_bar_visualizations':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'HorizontalBarViz':
                    return super().__getitem__(i)
            input_name = schemas.StrSchema
            __annotations__ = {
                "type": type,
                "horizontal_bar_visualizations": horizontal_bar_visualizations,
                "input_name": input_name,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    horizontal_bar_visualizations: MetaOapg.properties.horizontal_bar_visualizations
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["horizontal_bar_visualizations"]) -> MetaOapg.properties.horizontal_bar_visualizations: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["input_name"]) -> MetaOapg.properties.input_name: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["horizontal_bar_visualizations"], typing_extensions.Literal["type"], typing_extensions.Literal["input_name"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["horizontal_bar_visualizations"]) -> MetaOapg.properties.horizontal_bar_visualizations: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["input_name"]) -> typing.Union[MetaOapg.properties.input_name, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["horizontal_bar_visualizations"], typing_extensions.Literal["type"], typing_extensions.Literal["input_name"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        horizontal_bar_visualizations: typing.Union[MetaOapg.properties.horizontal_bar_visualizations, list, tuple, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        input_name: typing.Union[MetaOapg.properties.input_name, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'HorizontalBarScatterLabel':
        return super().__new__(
            cls,
            *args,
            horizontal_bar_visualizations=horizontal_bar_visualizations,
            type=type,
            input_name=input_name,
            _configuration=_configuration,
        )

from openapi_client.model.horizontal_bar_viz import HorizontalBarViz
