# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class CustomVisualizationType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "Bar": "BAR",
            "Line": "LINE",
            "Area": "AREA",
            "Table": "TABLE",
            "Heatmap": "HEATMAP",
            "Donut": "DONUT",
            "Confusion Matrix": "CONFUSION_MATRIX",
        }
    
    @schemas.classproperty
    def BAR(cls):
        return cls("Bar")
    
    @schemas.classproperty
    def LINE(cls):
        return cls("Line")
    
    @schemas.classproperty
    def AREA(cls):
        return cls("Area")
    
    @schemas.classproperty
    def TABLE(cls):
        return cls("Table")
    
    @schemas.classproperty
    def HEATMAP(cls):
        return cls("Heatmap")
    
    @schemas.classproperty
    def DONUT(cls):
        return cls("Donut")
    
    @schemas.classproperty
    def CONFUSION_MATRIX(cls):
        return cls("Confusion Matrix")
