# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ScatterInsightType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "redundant_samples_cluster": "REDUNDANT_SAMPLES_CLUSTER",
            "weak_cluster": "WEAK_CLUSTER",
            "under_representation_cluster": "UNDER_REPRESENTATION_CLUSTER",
            "overfitting_cluster": "OVERFITTING_CLUSTER",
        }
    
    @schemas.classproperty
    def REDUNDANT_SAMPLES_CLUSTER(cls):
        return cls("redundant_samples_cluster")
    
    @schemas.classproperty
    def WEAK_CLUSTER(cls):
        return cls("weak_cluster")
    
    @schemas.classproperty
    def UNDER_REPRESENTATION_CLUSTER(cls):
        return cls("under_representation_cluster")
    
    @schemas.classproperty
    def OVERFITTING_CLUSTER(cls):
        return cls("overfitting_cluster")
