# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class MultiThresholdConfusionMatrixParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "modelExtIds",
            "customMetricName",
        }
        
        class properties:
            
            
            class modelExtIds(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'modelExtIds':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            customMetricName = schemas.StrSchema
            verticalSplit = schemas.StrSchema
            horizontalSplit = schemas.StrSchema
            
            
            class filters(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ESFilter']:
                        return ESFilter
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ESFilter'], typing.List['ESFilter']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'filters':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ESFilter':
                    return super().__getitem__(i)
            __annotations__ = {
                "modelExtIds": modelExtIds,
                "customMetricName": customMetricName,
                "verticalSplit": verticalSplit,
                "horizontalSplit": horizontalSplit,
                "filters": filters,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    modelExtIds: MetaOapg.properties.modelExtIds
    customMetricName: MetaOapg.properties.customMetricName
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelExtIds"]) -> MetaOapg.properties.modelExtIds: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customMetricName"]) -> MetaOapg.properties.customMetricName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verticalSplit"]) -> MetaOapg.properties.verticalSplit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["horizontalSplit"]) -> MetaOapg.properties.horizontalSplit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["filters"]) -> MetaOapg.properties.filters: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["modelExtIds"], typing_extensions.Literal["customMetricName"], typing_extensions.Literal["verticalSplit"], typing_extensions.Literal["horizontalSplit"], typing_extensions.Literal["filters"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelExtIds"]) -> MetaOapg.properties.modelExtIds: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customMetricName"]) -> MetaOapg.properties.customMetricName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verticalSplit"]) -> typing.Union[MetaOapg.properties.verticalSplit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["horizontalSplit"]) -> typing.Union[MetaOapg.properties.horizontalSplit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["filters"]) -> typing.Union[MetaOapg.properties.filters, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["modelExtIds"], typing_extensions.Literal["customMetricName"], typing_extensions.Literal["verticalSplit"], typing_extensions.Literal["horizontalSplit"], typing_extensions.Literal["filters"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        modelExtIds: typing.Union[MetaOapg.properties.modelExtIds, list, tuple, ],
        customMetricName: typing.Union[MetaOapg.properties.customMetricName, str, ],
        verticalSplit: typing.Union[MetaOapg.properties.verticalSplit, str, schemas.Unset] = schemas.unset,
        horizontalSplit: typing.Union[MetaOapg.properties.horizontalSplit, str, schemas.Unset] = schemas.unset,
        filters: typing.Union[MetaOapg.properties.filters, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'MultiThresholdConfusionMatrixParams':
        return super().__new__(
            cls,
            *args,
            modelExtIds=modelExtIds,
            customMetricName=customMetricName,
            verticalSplit=verticalSplit,
            horizontalSplit=horizontalSplit,
            filters=filters,
            _configuration=_configuration,
        )

from openapi_client.model.es_filter import ESFilter
