# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from openapi_client.paths.auth_activate.post import Activate
from openapi_client.paths.dashboards_add_dashboard.post import AddDashboard
from openapi_client.paths.datasets_add_dataset.post import AddDataset
from openapi_client.paths.jobs_add_export_model_job.post import AddExportModelJob
from openapi_client.paths.issues_add_issue.post import AddIssue
from openapi_client.paths.projects_add_project.post import AddProject
from openapi_client.paths.secret_manager_add_secret_manager.post import AddSecretManager
from openapi_client.paths.versions_add_version.post import AddVersion
from openapi_client.paths.jobs_continue_train.post import ContinueTrain
from openapi_client.paths.model_tests_create_model_test.post import CreateModelTest
from openapi_client.paths.organizations_create_organization.post import CreateOrganization
from openapi_client.paths.dashboards_delete_dashboard.post import DeleteDashboard
from openapi_client.paths.issues_delete_issue.post import DeleteIssue
from openapi_client.paths.models_delete_model.post import DeleteModel
from openapi_client.paths.model_tests_delete_model_test.post import DeleteModelTest
from openapi_client.paths.organizations_delete_organization.post import DeleteOrganization
from openapi_client.paths.projects_delete_project.post import DeleteProject
from openapi_client.paths.users_delete_user_by_id.post import DeleteUserById
from openapi_client.paths.versions_delete_version.post import DeleteVersion
from openapi_client.paths.visualizations_delete_visualizations.post import DeleteVisualizations
from openapi_client.paths.jobs_evaluate.post import Evaluate
from openapi_client.paths.auth_extend_trial.post import ExtendTrial
from openapi_client.paths.model_tests_get_all_project_model_tests.post import GetAllProjectModelTests
from openapi_client.paths.users_get_all_slim_user_data.post import GetAllSlimUserData
from openapi_client.paths.modelmetrics_get_balanced_accuracy.post import GetBalancedAccuracy
from openapi_client.paths.modelmetrics_get_confusion_metric_names.post import GetConfusionMetricNames
from openapi_client.paths.projects_get_current_project_version.post import GetCurrentProjectVersion
from openapi_client.paths.dashboards_get_dashboard.post import GetDashboard
from openapi_client.paths.dashboards_get_dashlet_fields.post import GetDashletFields
from openapi_client.paths.datasets_get_dataset_version.post import GetDatasetVersion
from openapi_client.paths.datasets_get_dataset_versions.post import GetDatasetVersions
from openapi_client.paths.datasets_get_datasets.post import GetDatasets
from openapi_client.paths.demos_get_demos.post import GetDemos
from openapi_client.paths.exportedmodels_get_exported_model_jobs.post import GetExportedModelJobs
from openapi_client.paths.modelmetrics_get_f1_score.post import GetF1Score
from openapi_client.paths.modelmetrics_get_heatmap_chart.post import GetHeatmapChart
from openapi_client.paths.jobs_get_jobs.post import GetJobs
from openapi_client.paths.dashboards_get_kibana_dashboards.post import GetKibanaDashboards
from openapi_client.paths.dashboards_get_kibana_dashlet_fields.post import GetKibanaDashletFields
from openapi_client.paths.datasets_get_latest_dataset_version.post import GetLatestDatasetVersion
from openapi_client.paths.jobs_get_machine_types.post import GetMachineTypes
from openapi_client.paths.metadata_get_max_active_users.post import GetMaxActiveUsers
from openapi_client.paths.modelmetrics_get_model_epoch_loss.post import GetModelEpochLoss
from openapi_client.paths.insights_get_model_insights.post import GetModelInsights
from openapi_client.paths.model_tests_get_model_test_result.post import GetModelTestResult
from openapi_client.paths.visualizations_get_model_visualizations.post import GetModelVisualizations
from openapi_client.paths.models_get_models_by_hash.post import GetModelsByHash
from openapi_client.paths.models_get_models_by_version_id.post import GetModelsByVersionId
from openapi_client.paths.notifications_get_notifications.post import GetNotifications
from openapi_client.paths.jobs_get_organization_jobs.post import GetOrganizationJobs
from openapi_client.paths.users_get_organization_slim_user_data.post import GetOrganizationSlimUserData
from openapi_client.paths.organizations_get_organizations.post import GetOrganizations
from openapi_client.paths.modelmetrics_get_pr_curve.post import GetPrCurve
from openapi_client.paths.dashboards_get_project_dashboards.post import GetProjectDashboards
from openapi_client.paths.issues_get_project_issues.post import GetProjectIssues
from openapi_client.paths.versions_get_project_slim_versions.post import GetProjectSlimVersions
from openapi_client.paths.projects_get_projects.post import GetProjects
from openapi_client.paths.models_get_recent_organization_models.post import GetRecentOrganizationModels
from openapi_client.paths.modelmetrics_get_roc.post import GetRoc
from openapi_client.paths.secret_manager_get_secret_manager_list.post import GetSecretManagerList
from openapi_client.paths.issues_get_single_issue.post import GetSingleIssue
from openapi_client.paths.model_tests_get_single_model_test.post import GetSingleModelTest
from openapi_client.paths.metadata_get_statistics.post import GetStatistics
from openapi_client.paths.exportedmodels_get_stored_exported_model_resource_url.post import GetStoredExportedModelResourceUrl
from openapi_client.paths.visualizations_get_stored_resource_url.post import GetStoredResourceUrl
from openapi_client.paths.modelmetrics_get_table_chart.post import GetTableChart
from openapi_client.paths.jobs_get_training_jobs.post import GetTrainingJobs
from openapi_client.paths.versions_get_upload_signed_url.post import GetUploadSignedUrl
from openapi_client.paths.visualizations_get_visualization.post import GetVisualization
from openapi_client.paths.modelmetrics_get_xy_chart.post import GetXyChart
from openapi_client.paths.monitor_health_check.get import HealthCheck
from openapi_client.paths.demos_import_demo_project.post import ImportDemoProject
from openapi_client.paths.versions_import_model.post import ImportModel
from openapi_client.paths.jobs_is_training_job_running.post import IsTrainingJobRunning
from openapi_client.paths.auth_keygen.post import KeyGen
from openapi_client.paths.auth_keylogin.post import KeyLogin
from openapi_client.paths.projects_load_model.post import LoadModel
from openapi_client.paths.versions_load_version.post import LoadVersion
from openapi_client.paths.auth_login.post import Login
from openapi_client.paths.auth_logout.post import Logout
from openapi_client.paths.datasets_modify_dataset_version_note.post import ModifyDatasetVersionNote
from openapi_client.paths.datasets_parse_dataset.post import ParseDataset
from openapi_client.paths.jobs_population_exploration.post import PopulationExploration
from openapi_client.paths.auth_request_trial.post import RequestTrial
from openapi_client.paths.auth_resend_activation_mail.post import ResendActivationMail
from openapi_client.paths.auth_reset_password.post import ResetPassword
from openapi_client.paths.jobs_sample_analysis.post import SampleAnalysis
from openapi_client.paths.jobs_sample_selection.post import SampleSelection
from openapi_client.paths.visualizations_save_analyzer_layout.post import SaveAnalyzerLayout
from openapi_client.paths.datasets_save_dataset_version.post import SaveDatasetVersion
from openapi_client.paths.auth_send_reset_password_mail.post import SendResetPasswordMail
from openapi_client.paths.demos_send_user_message.post import SendUserMessage
from openapi_client.paths.organizations_set_default_organization.post import SetDefaultOrganization
from openapi_client.paths.jobs_set_machine_type.post import SetOrganizationMachineType
from openapi_client.paths.auth_set_user_metadata.post import SetUserMetadata
from openapi_client.paths.notifications_set_user_notifications_as_read.post import SetUserNotificationsAsRead
from openapi_client.paths.auth_signup.post import Signup
from openapi_client.paths.auth_start_trial.post import StartTrial
from openapi_client.paths.jobs_stop_job.post import StopJob
from openapi_client.paths.jobs_terminate_job.post import TerminateJob
from openapi_client.paths.jobs_train_from_initial_weights.post import TrainFromInitialWeights
from openapi_client.paths.jobs_train_from_scratch.post import TrainFromScratch
from openapi_client.paths.datasets_trash_dataset.post import TrashDataset
from openapi_client.paths.projects_trash_project.post import TrashProject
from openapi_client.paths.secret_manager_trash_secret_manager.post import TrashSecretManager
from openapi_client.paths.dashboards_update_dashboard.post import UpdateDashboard
from openapi_client.paths.issues_update_issue.post import UpdateIssue
from openapi_client.paths.model_tests_update_model_test.post import UpdateModelTest
from openapi_client.paths.organizations_update_organization_public_name.post import UpdateOrganizationPublicName
from openapi_client.paths.secret_manager_update_secret_manager.post import UpdateSecretManager
from openapi_client.paths.users_update_user_name.post import UpdateUserName
from openapi_client.paths.users_update_user_organization.post import UpdateUserOrganization
from openapi_client.paths.users_update_user_role.post import UpdateUserRole
from openapi_client.paths.users_update_user_status.post import UpdateUserStatus
from openapi_client.paths.versions_update_version.post import UpdateVersion
from openapi_client.paths.jobs_warmup.post import Warmup
from openapi_client.paths.auth_who_am_i.post import WhoAmI


class DefaultApi(
    Activate,
    AddDashboard,
    AddDataset,
    AddExportModelJob,
    AddIssue,
    AddProject,
    AddSecretManager,
    AddVersion,
    ContinueTrain,
    CreateModelTest,
    CreateOrganization,
    DeleteDashboard,
    DeleteIssue,
    DeleteModel,
    DeleteModelTest,
    DeleteOrganization,
    DeleteProject,
    DeleteUserById,
    DeleteVersion,
    DeleteVisualizations,
    Evaluate,
    ExtendTrial,
    GetAllProjectModelTests,
    GetAllSlimUserData,
    GetBalancedAccuracy,
    GetConfusionMetricNames,
    GetCurrentProjectVersion,
    GetDashboard,
    GetDashletFields,
    GetDatasetVersion,
    GetDatasetVersions,
    GetDatasets,
    GetDemos,
    GetExportedModelJobs,
    GetF1Score,
    GetHeatmapChart,
    GetJobs,
    GetKibanaDashboards,
    GetKibanaDashletFields,
    GetLatestDatasetVersion,
    GetMachineTypes,
    GetMaxActiveUsers,
    GetModelEpochLoss,
    GetModelInsights,
    GetModelTestResult,
    GetModelVisualizations,
    GetModelsByHash,
    GetModelsByVersionId,
    GetNotifications,
    GetOrganizationJobs,
    GetOrganizationSlimUserData,
    GetOrganizations,
    GetPrCurve,
    GetProjectDashboards,
    GetProjectIssues,
    GetProjectSlimVersions,
    GetProjects,
    GetRecentOrganizationModels,
    GetRoc,
    GetSecretManagerList,
    GetSingleIssue,
    GetSingleModelTest,
    GetStatistics,
    GetStoredExportedModelResourceUrl,
    GetStoredResourceUrl,
    GetTableChart,
    GetTrainingJobs,
    GetUploadSignedUrl,
    GetVisualization,
    GetXyChart,
    HealthCheck,
    ImportDemoProject,
    ImportModel,
    IsTrainingJobRunning,
    KeyGen,
    KeyLogin,
    LoadModel,
    LoadVersion,
    Login,
    Logout,
    ModifyDatasetVersionNote,
    ParseDataset,
    PopulationExploration,
    RequestTrial,
    ResendActivationMail,
    ResetPassword,
    SampleAnalysis,
    SampleSelection,
    SaveAnalyzerLayout,
    SaveDatasetVersion,
    SendResetPasswordMail,
    SendUserMessage,
    SetDefaultOrganization,
    SetOrganizationMachineType,
    SetUserMetadata,
    SetUserNotificationsAsRead,
    Signup,
    StartTrial,
    StopJob,
    TerminateJob,
    TrainFromInitialWeights,
    TrainFromScratch,
    TrashDataset,
    TrashProject,
    TrashSecretManager,
    UpdateDashboard,
    UpdateIssue,
    UpdateModelTest,
    UpdateOrganizationPublicName,
    UpdateSecretManager,
    UpdateUserName,
    UpdateUserOrganization,
    UpdateUserRole,
    UpdateUserStatus,
    UpdateVersion,
    Warmup,
    WhoAmI,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
