# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class AddIssueParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "title",
            "projectId",
            "status",
        }
        
        class properties:
            projectId = schemas.StrSchema
            title = schemas.StrSchema
        
            @staticmethod
            def status() -> typing.Type['IssueStatus']:
                return IssueStatus
            branch = schemas.StrSchema
            
            
            class tags(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'tags':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            assignment = schemas.StrSchema
            
            
            class activities(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['IssueActivity']:
                        return IssueActivity
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['IssueActivity'], typing.List['IssueActivity']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'activities':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'IssueActivity':
                    return super().__getitem__(i)
            __annotations__ = {
                "projectId": projectId,
                "title": title,
                "status": status,
                "branch": branch,
                "tags": tags,
                "assignment": assignment,
                "activities": activities,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    title: MetaOapg.properties.title
    projectId: MetaOapg.properties.projectId
    status: 'IssueStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'IssueStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["branch"]) -> MetaOapg.properties.branch: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tags"]) -> MetaOapg.properties.tags: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["assignment"]) -> MetaOapg.properties.assignment: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["activities"]) -> MetaOapg.properties.activities: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["title"], typing_extensions.Literal["projectId"], typing_extensions.Literal["status"], typing_extensions.Literal["branch"], typing_extensions.Literal["tags"], typing_extensions.Literal["assignment"], typing_extensions.Literal["activities"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["projectId"]) -> MetaOapg.properties.projectId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'IssueStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["branch"]) -> typing.Union[MetaOapg.properties.branch, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tags"]) -> typing.Union[MetaOapg.properties.tags, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["assignment"]) -> typing.Union[MetaOapg.properties.assignment, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["activities"]) -> typing.Union[MetaOapg.properties.activities, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["title"], typing_extensions.Literal["projectId"], typing_extensions.Literal["status"], typing_extensions.Literal["branch"], typing_extensions.Literal["tags"], typing_extensions.Literal["assignment"], typing_extensions.Literal["activities"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        title: typing.Union[MetaOapg.properties.title, str, ],
        projectId: typing.Union[MetaOapg.properties.projectId, str, ],
        status: 'IssueStatus',
        branch: typing.Union[MetaOapg.properties.branch, str, schemas.Unset] = schemas.unset,
        tags: typing.Union[MetaOapg.properties.tags, list, tuple, schemas.Unset] = schemas.unset,
        assignment: typing.Union[MetaOapg.properties.assignment, str, schemas.Unset] = schemas.unset,
        activities: typing.Union[MetaOapg.properties.activities, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AddIssueParams':
        return super().__new__(
            cls,
            *args,
            title=title,
            projectId=projectId,
            status=status,
            branch=branch,
            tags=tags,
            assignment=assignment,
            activities=activities,
            _configuration=_configuration,
        )

from openapi_client.model.issue_activity import IssueActivity
from openapi_client.model.issue_status import IssueStatus
