# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class FilterOperatorType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "between": "BETWEEN",
            "not-between": "NOTBETWEEN",
            "equal": "EQUAL",
            "not-equal": "NOTEQUAL",
            "in": "IN",
            "greater-than": "GREATERTHAN",
            "less-than": "LESSTHAN",
        }
    
    @schemas.classproperty
    def BETWEEN(cls):
        return cls("between")
    
    @schemas.classproperty
    def NOTBETWEEN(cls):
        return cls("not-between")
    
    @schemas.classproperty
    def EQUAL(cls):
        return cls("equal")
    
    @schemas.classproperty
    def NOTEQUAL(cls):
        return cls("not-equal")
    
    @schemas.classproperty
    def IN(cls):
        return cls("in")
    
    @schemas.classproperty
    def GREATERTHAN(cls):
        return cls("greater-than")
    
    @schemas.classproperty
    def LESSTHAN(cls):
        return cls("less-than")
