# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class DataTypeEnum(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "image": "IMAGE",
            "word": "WORD",
            "text": "TEXT",
            "mask_text": "MASK_TEXT",
            "graph": "GRAPH",
            "hbar": "HBAR",
            "bbox_image": "BBOX_IMAGE",
            "mask_image": "MASK_IMAGE",
        }
    
    @schemas.classproperty
    def IMAGE(cls):
        return cls("image")
    
    @schemas.classproperty
    def WORD(cls):
        return cls("word")
    
    @schemas.classproperty
    def TEXT(cls):
        return cls("text")
    
    @schemas.classproperty
    def MASK_TEXT(cls):
        return cls("mask_text")
    
    @schemas.classproperty
    def GRAPH(cls):
        return cls("graph")
    
    @schemas.classproperty
    def HBAR(cls):
        return cls("hbar")
    
    @schemas.classproperty
    def BBOX_IMAGE(cls):
        return cls("bbox_image")
    
    @schemas.classproperty
    def MASK_IMAGE(cls):
        return cls("mask_image")
