# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Aggregations(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "field",
            "aggregation",
        }
        
        class properties:
            field = schemas.StrSchema
        
            @staticmethod
            def aggregation() -> typing.Type['AggregationMethod']:
                return AggregationMethod
            __annotations__ = {
                "field": field,
                "aggregation": aggregation,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    field: MetaOapg.properties.field
    aggregation: 'AggregationMethod'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["field"]) -> MetaOapg.properties.field: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["aggregation"]) -> 'AggregationMethod': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["field"], typing_extensions.Literal["aggregation"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["field"]) -> MetaOapg.properties.field: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["aggregation"]) -> 'AggregationMethod': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["field"], typing_extensions.Literal["aggregation"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        field: typing.Union[MetaOapg.properties.field, str, ],
        aggregation: 'AggregationMethod',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Aggregations':
        return super().__new__(
            cls,
            *args,
            field=field,
            aggregation=aggregation,
            _configuration=_configuration,
        )

from openapi_client.model.aggregation_method import AggregationMethod
