# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class BoundingBox(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "confidence",
            "width",
            "x",
            "y",
            "label",
            "height",
        }
        
        class properties:
            x = schemas.Float64Schema
            y = schemas.Float64Schema
            width = schemas.Float64Schema
            height = schemas.Float64Schema
            confidence = schemas.Float64Schema
            label = schemas.StrSchema
            __annotations__ = {
                "x": x,
                "y": y,
                "width": width,
                "height": height,
                "confidence": confidence,
                "label": label,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    confidence: MetaOapg.properties.confidence
    width: MetaOapg.properties.width
    x: MetaOapg.properties.x
    y: MetaOapg.properties.y
    label: MetaOapg.properties.label
    height: MetaOapg.properties.height
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["confidence"]) -> MetaOapg.properties.confidence: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["width"]) -> MetaOapg.properties.width: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["x"]) -> MetaOapg.properties.x: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["y"]) -> MetaOapg.properties.y: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["height"]) -> MetaOapg.properties.height: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["confidence"], typing_extensions.Literal["width"], typing_extensions.Literal["x"], typing_extensions.Literal["y"], typing_extensions.Literal["label"], typing_extensions.Literal["height"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["confidence"]) -> MetaOapg.properties.confidence: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["width"]) -> MetaOapg.properties.width: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["x"]) -> MetaOapg.properties.x: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["y"]) -> MetaOapg.properties.y: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["height"]) -> MetaOapg.properties.height: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["confidence"], typing_extensions.Literal["width"], typing_extensions.Literal["x"], typing_extensions.Literal["y"], typing_extensions.Literal["label"], typing_extensions.Literal["height"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        confidence: typing.Union[MetaOapg.properties.confidence, decimal.Decimal, int, float, ],
        width: typing.Union[MetaOapg.properties.width, decimal.Decimal, int, float, ],
        x: typing.Union[MetaOapg.properties.x, decimal.Decimal, int, float, ],
        y: typing.Union[MetaOapg.properties.y, decimal.Decimal, int, float, ],
        label: typing.Union[MetaOapg.properties.label, str, ],
        height: typing.Union[MetaOapg.properties.height, decimal.Decimal, int, float, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'BoundingBox':
        return super().__new__(
            cls,
            *args,
            confidence=confidence,
            width=width,
            x=x,
            y=y,
            label=label,
            height=height,
            _configuration=_configuration,
        )
