# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class CustomMessageData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "level",
            "params",
        }
        
        class properties:
        
            @staticmethod
            def level() -> typing.Type['MessageLevel']:
                return MessageLevel
        
            @staticmethod
            def params() -> typing.Type['CustomMessageDataParams']:
                return CustomMessageDataParams
            __annotations__ = {
                "level": level,
                "params": params,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    level: 'MessageLevel'
    params: 'CustomMessageDataParams'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["level"]) -> 'MessageLevel': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["params"]) -> 'CustomMessageDataParams': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["level"], typing_extensions.Literal["params"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["level"]) -> 'MessageLevel': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["params"]) -> 'CustomMessageDataParams': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["level"], typing_extensions.Literal["params"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        level: 'MessageLevel',
        params: 'CustomMessageDataParams',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'CustomMessageData':
        return super().__new__(
            cls,
            *args,
            level=level,
            params=params,
            _configuration=_configuration,
        )

from openapi_client.model.custom_message_data_params import CustomMessageDataParams
from openapi_client.model.message_level import MessageLevel
