# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_client
from openapi_client.model.visualization_response import VisualizationResponse
from openapi_client import configuration


class TestVisualizationResponse(unittest.TestCase):
    """VisualizationResponse unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
