# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Metric(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "MeanSquaredError": "MEAN_SQUARED_ERROR",
            "MeanSquaredLogarithmicError": "MEAN_SQUARED_LOGARITHMIC_ERROR",
            "MeanAbsoluteError": "MEAN_ABSOLUTE_ERROR",
            "MeanAbsolutePercentageError": "MEAN_ABSOLUTE_PERCENTAGE_ERROR",
            "Accuracy": "ACCURACY",
            "BinaryAccuracy": "BINARY_ACCURACY",
            "MeanIOU": "MEAN_IOU",
            "ConfusionMatrixClassification": "CONFUSION_MATRIX_CLASSIFICATION",
            "ConfusionMatrixBinaryClassification": "CONFUSION_MATRIX_BINARY_CLASSIFICATION",
        }
    
    @schemas.classproperty
    def MEAN_SQUARED_ERROR(cls):
        return cls("MeanSquaredError")
    
    @schemas.classproperty
    def MEAN_SQUARED_LOGARITHMIC_ERROR(cls):
        return cls("MeanSquaredLogarithmicError")
    
    @schemas.classproperty
    def MEAN_ABSOLUTE_ERROR(cls):
        return cls("MeanAbsoluteError")
    
    @schemas.classproperty
    def MEAN_ABSOLUTE_PERCENTAGE_ERROR(cls):
        return cls("MeanAbsolutePercentageError")
    
    @schemas.classproperty
    def ACCURACY(cls):
        return cls("Accuracy")
    
    @schemas.classproperty
    def BINARY_ACCURACY(cls):
        return cls("BinaryAccuracy")
    
    @schemas.classproperty
    def MEAN_IOU(cls):
        return cls("MeanIOU")
    
    @schemas.classproperty
    def CONFUSION_MATRIX_CLASSIFICATION(cls):
        return cls("ConfusionMatrixClassification")
    
    @schemas.classproperty
    def CONFUSION_MATRIX_BINARY_CLASSIFICATION(cls):
        return cls("ConfusionMatrixBinaryClassification")
