# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_client.paths.metadata_get_max_active_users import Api

from openapi_client.paths import PathValues

path = PathValues.METADATA_GET_MAX_ACTIVE_USERS