# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class DatasetMetadata(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "script",
        }
        
        class properties:
            script = schemas.StrSchema
        
            @staticmethod
            def setup() -> typing.Type['DatasetSetup']:
                return DatasetSetup
        
            @staticmethod
            def setupStatus() -> typing.Type['DatasetSetupStatus']:
                return DatasetSetupStatus
        
            @staticmethod
            def modelSetup() -> typing.Type['ModelSetup']:
                return ModelSetup
            secretManagerId = schemas.StrSchema
            __annotations__ = {
                "script": script,
                "setup": setup,
                "setupStatus": setupStatus,
                "modelSetup": modelSetup,
                "secretManagerId": secretManagerId,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    script: MetaOapg.properties.script
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["script"]) -> MetaOapg.properties.script: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["setup"]) -> 'DatasetSetup': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["setupStatus"]) -> 'DatasetSetupStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelSetup"]) -> 'ModelSetup': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["secretManagerId"]) -> MetaOapg.properties.secretManagerId: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["script"], typing_extensions.Literal["setup"], typing_extensions.Literal["setupStatus"], typing_extensions.Literal["modelSetup"], typing_extensions.Literal["secretManagerId"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["script"]) -> MetaOapg.properties.script: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["setup"]) -> typing.Union['DatasetSetup', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["setupStatus"]) -> typing.Union['DatasetSetupStatus', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelSetup"]) -> typing.Union['ModelSetup', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["secretManagerId"]) -> typing.Union[MetaOapg.properties.secretManagerId, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["script"], typing_extensions.Literal["setup"], typing_extensions.Literal["setupStatus"], typing_extensions.Literal["modelSetup"], typing_extensions.Literal["secretManagerId"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        script: typing.Union[MetaOapg.properties.script, str, ],
        setup: typing.Union['DatasetSetup', schemas.Unset] = schemas.unset,
        setupStatus: typing.Union['DatasetSetupStatus', schemas.Unset] = schemas.unset,
        modelSetup: typing.Union['ModelSetup', schemas.Unset] = schemas.unset,
        secretManagerId: typing.Union[MetaOapg.properties.secretManagerId, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'DatasetMetadata':
        return super().__new__(
            cls,
            *args,
            script=script,
            setup=setup,
            setupStatus=setupStatus,
            modelSetup=modelSetup,
            secretManagerId=secretManagerId,
            _configuration=_configuration,
        )

from openapi_client.model.dataset_setup import DatasetSetup
from openapi_client.model.dataset_setup_status import DatasetSetupStatus
from openapi_client.model.model_setup import ModelSetup
